@font-face {
    font-family: 'Roboto';
    font-style: normal;
    font-weight: 400;
    src: url(https://fonts.gstatic.com/s/roboto/v18/KFOmCnqEu92Fr1Mu72xKOzY.woff2)format('woff2');
}

body {
    color: #3c4043;
    font-family: Roboto, 'Helvetica Neue', Helvetica, sans-serif;
    line-height: 1.25rem;
}

.search-container {
    margin-top: 3rem;
}

.search-greeting-logo {
    height: 3.5rem;
    width: 3.5rem;
}

.search-greeting {
    color: #324A5E;
    font-size: 1.75rem;
    font-weight: 400;
    line-height: 2.25rem;
    text-align: center;
}

.search-greeting-logo-container {
    height: 3.5rem;
    margin: 0 auto 1.125rem auto;
    padding: .5rem;
    width: 3.5rem;
}

.search-form {
    margin: 0 auto;
    padding: 0 0 2.5rem;
    width: 32.5rem;
    position: relative;
}

.search-input::placeholder {
    color: #5f6368;
}

.search-input {
    background-color: #ffffff;
    border: none;
    border-radius: .5rem;
    box-shadow: 0 1px 2px 0 rgba(60, 64, 67, .30), 0 1px 3px 1px rgba(60, 64, 67, .15);
    box-sizing: border-box;
    color: #202124;
    display: block;
    font-size: 1rem;
    height: 3rem;
    padding: 0 2.5rem 0 4.5rem;
    width: 100%;
    -webkit-appearance: none;
}

.search-search-button,
.search-clear-button {
    cursor: pointer;
}

.search-search-button,
.search-clear-button {
    background-color: transparent;
    border: none;
    cursor: pointer;
    height: 3rem;
    padding: 0;
    position: absolute;
    left: 1.5rem;
    top: 0;
    width: 3rem;
}

.search-search-icon {
    fill: #3c4043;
    height: 3rem;
    width: 1.5rem;
}

.tiles-container {
	width: 100%;
	display: flex;
    justify-content: center;
    margin-top: 2rem;
}

section {
    max-width: 44.5rem;
    padding: 0;
    color: #3c4043;
    line-height: 1.25rem;
}

section ul {
    margin: 0;
    outline: 0;
    padding: 0;
    display: inline-block;
    max-width: 44.5rem;
}

section li {
    min-height: 3.125rem;
    vertical-align: top;
    display: inline-block;
}

section li > a {
    max-height: 7rem;
    padding: 0.5rem;
    margin: 0.5rem;
    border: .0625rem solid #dadce0;
    border-radius: .5rem;
    display: block;
}

section li img {
    width: 4rem;
    height: auto;
    display: block;
    margin-left: auto;
    margin-right: auto;
}

section li span {
    height: auto;
    display: block;
    margin: .5rem 0;
    text-align: center;
}
